package main

import (
	openapi "github.com/alibabacloud-go/darabonba-openapi/v2/client"
	iot20180120 "github.com/alibabacloud-go/iot-20180120/v6/client"
	util "github.com/alibabacloud-go/tea-utils/v2/service"
	"github.com/alibabacloud-go/tea/tea"
)

func CreateClient(accessKeyId *string, accessKeySecret *string, endpoint *string) (_result *iot20180120.Client, _err error) {
	config := &openapi.Config{
		// 必填，您的 AccessKey ID
		AccessKeyId: accessKeyId,
		// 必填，您的 AccessKey Secret
		AccessKeySecret: accessKeySecret,
	}
	// Endpoint 请参考 https://api.aliyun.com/product/Iot
	// config.Endpoint = tea.String("iot.cn-shanghai.aliyuncs.com")
	config.Endpoint = endpoint
	_result = &iot20180120.Client{}
	_result, _err = iot20180120.NewClient(config)
	return _result, _err
}

func getSnapshotApi(accessKeyId *string, accessKeySecret *string, endpoint *string, iotInstanceId *string, productKey *string,
	deviceName *string) (queryDevicePropertyStatusResponse *iot20180120.QueryDevicePropertyStatusResponse, _err error) {
	client, _err := CreateClient(accessKeyId, accessKeySecret, endpoint)
	if _err != nil {
		return nil, _err
	}

	queryDevicePropertyStatusRequest := &iot20180120.QueryDevicePropertyStatusRequest{}
	queryDevicePropertyStatusRequest.IotInstanceId = iotInstanceId
	queryDevicePropertyStatusRequest.ProductKey = productKey
	queryDevicePropertyStatusRequest.DeviceName = deviceName

	queryDevicePropertyStatusResponse = &iot20180120.QueryDevicePropertyStatusResponse{}

	runtime := &util.RuntimeOptions{}
	tryErr := func() (_e error) {
		defer func() {
			if r := tea.Recover(recover()); r != nil {
				_e = r
			}
		}()
		queryDevicePropertyStatusResponse, _err = client.QueryDevicePropertyStatusWithOptions(queryDevicePropertyStatusRequest, runtime)

		if _err != nil {
			return _err
		}

		return nil
	}()

	if tryErr != nil {
		var error = &tea.SDKError{}
		if _t, ok := tryErr.(*tea.SDKError); ok {
			error = _t
		} else {
			error.Message = tea.String(tryErr.Error())
		}
		// 如有需要，请打印 error
		_, _err = util.AssertAsString(error.Message)
		if _err != nil {
			return queryDevicePropertyStatusResponse, _err
		}
	}
	return queryDevicePropertyStatusResponse, _err
}

func getSnapshotTopicApi(accessKeyId *string, accessKeySecret *string, endpoint *string, iotInstanceId *string, productKey *string,
	deviceName *string, asc *int32, pageSize *int32, userTopic *string) (queryDevicesHotStorageDataStatusResponse *iot20180120.QueryDevicesHotStorageDataStatusResponse, _err error) {

	client, _err := CreateClient(accessKeyId, accessKeySecret, endpoint)
	if _err != nil {
		return nil, _err
	}

	queryDevicesHotStorageDataStatusRequest := &iot20180120.QueryDevicesHotStorageDataStatusRequest{}
	queryDevicesHotStorageDataStatusRequest.IotInstanceId = iotInstanceId
	queryDevicesHotStorageDataStatusRequest.ProductKey = productKey
	queryDevicesHotStorageDataStatusRequest.DeviceName = deviceName
	queryDevicesHotStorageDataStatusRequest.Asc = asc
	queryDevicesHotStorageDataStatusRequest.PageSize = pageSize
	queryDevicesHotStorageDataStatusRequest.UserTopic = userTopic

	queryDevicesHotStorageDataStatusResponse = &iot20180120.QueryDevicesHotStorageDataStatusResponse{}

	runtime := &util.RuntimeOptions{}
	tryErr := func() (_e error) {
		defer func() {
			if r := tea.Recover(recover()); r != nil {
				_e = r
			}
		}()
		queryDevicesHotStorageDataStatusResponse, _err = client.QueryDevicesHotStorageDataStatusWithOptions(queryDevicesHotStorageDataStatusRequest, runtime)

		if _err != nil {
			return _err
		}

		return nil
	}()

	if tryErr != nil {
		var error = &tea.SDKError{}
		if _t, ok := tryErr.(*tea.SDKError); ok {
			error = _t
		} else {
			error.Message = tea.String(tryErr.Error())
		}
		// 如有需要，请打印 error
		_, _err = util.AssertAsString(error.Message)
		if _err != nil {
			return queryDevicesHotStorageDataStatusResponse, _err
		}
	}
	return queryDevicesHotStorageDataStatusResponse, _err
}

func getCustomSnapshotApi(accessKeyId *string, accessKeySecret *string, endpoint *string, iotInstanceId *string,
	tableName *string) (queryCustomTimelineTableStatusResponse *iot20180120.QueryCustomTimelineTableStatusResponse, _err error) {

	client, _err := CreateClient(accessKeyId, accessKeySecret, endpoint)
	if _err != nil {
		return nil, _err
	}

	queryCustomTimelineTableStatusRequest := &iot20180120.QueryCustomTimelineTableStatusRequest{}
	queryCustomTimelineTableStatusRequest.IotInstanceId = iotInstanceId
	queryCustomTimelineTableStatusRequest.TableName = tableName

	queryCustomTimelineTableStatusResponse = &iot20180120.QueryCustomTimelineTableStatusResponse{}

	runtime := &util.RuntimeOptions{}
	tryErr := func() (_e error) {
		defer func() {
			if r := tea.Recover(recover()); r != nil {
				_e = r
			}
		}()
		queryCustomTimelineTableStatusResponse, _err = client.QueryCustomTimelineTableStatusWithOptions(queryCustomTimelineTableStatusRequest, runtime)

		if _err != nil {
			return _err
		}

		return nil
	}()

	if tryErr != nil {
		var error = &tea.SDKError{}
		if _t, ok := tryErr.(*tea.SDKError); ok {
			error = _t
		} else {
			error.Message = tea.String(tryErr.Error())
		}
		// 如有需要，请打印 error
		_, _err = util.AssertAsString(error.Message)
		if _err != nil {
			return queryCustomTimelineTableStatusResponse, _err
		}
	}

	return queryCustomTimelineTableStatusResponse, _err
}
