package main

import (
	"net/http"

	"encoding/json"
	"strconv"
	"time"

	"github.com/alibabacloud-go/tea/tea"
	"github.com/prometheus/client_golang/prometheus"
	"github.com/prometheus/client_golang/prometheus/promhttp"
)

func testRaw() {
	go func() {
		for {
			queryDevicePropertyStatusResponse, _err := getSnapshotApi(tea.String(""), tea.String(""),
				tea.String(""), tea.String(""), tea.String(""), tea.String(""))
			queryDevicePropertyStatusResponseBodyDataListPropertyStatusInfo := queryDevicePropertyStatusResponse.Body.Data.List.PropertyStatusInfo
			var value *string = queryDevicePropertyStatusResponseBodyDataListPropertyStatusInfo[0].Value
			var floatValue float64
			floatValue, _ = strconv.ParseFloat(*value, 64)

			if _err != nil {
				panic(_err)
			}

			guageRaw.Set(floatValue)
			time.Sleep(3 * time.Second)
		}
	}()
}

func testTopic() {
	go func() {
		var asc int32 = 0
		var pageSize int32 = 1
		for {
			queryDevicesHotStorageDataStatusResponse, _err := getSnapshotTopicApi(tea.String(""), tea.String(""),
				tea.String(""), tea.String(""), tea.String(""), tea.String(""),
				&asc, &pageSize, tea.String(""))
			queryDevicesHotStorageDataStatusResponseBodyDataListPropertyStatusDataInfo := queryDevicesHotStorageDataStatusResponse.Body.Data.List.PropertyStatusDataInfo
			var value *string = queryDevicesHotStorageDataStatusResponseBodyDataListPropertyStatusDataInfo[0].Value
			var floatValue float64
			floatValue, _ = strconv.ParseFloat(*value, 64)

			if _err != nil {
				panic(_err)
			}

			guageTopic.Set(floatValue)
			time.Sleep(3 * time.Second)
		}
	}()
}

func testCustom() {
	go func() {
		for {
			queryCustomTimelineTableStatusResponse, _err := getCustomSnapshotApi(tea.String(""), tea.String(""),
				tea.String(""), tea.String(""), tea.String(""))

			var config []map[string]interface{}
			err := json.Unmarshal([]byte(*queryCustomTimelineTableStatusResponse.Body.Data.ResultJson), &config)

			if err != nil {
				panic(err)
			}

			if _err != nil {
				panic(_err)
			}

			guageCustom.Set(config[0]["avg_humidity"].(float64))
			time.Sleep(3 * time.Second)
		}
	}()
}

var (
	// 创建一个Gauge指标
	guageRaw = prometheus.NewGauge(prometheus.GaugeOpts{
		Name: "GolangRaw",  // 指标名称
		Help: "test value", // 指标帮助信息
	})
)

var (
	guageTopic = prometheus.NewGauge(prometheus.GaugeOpts{
		Name: "GolangTopic", // 指标名称
		Help: "test value",  // 指标帮助信息
	})
)

var (
	guageCustom = prometheus.NewGauge(prometheus.GaugeOpts{
		Name: "GolangCustom", // 指标名称
		Help: "test value",   // 指标帮助信息
	})
)

func main() {

	// 注册指标
	prometheus.MustRegister(guageRaw)
	prometheus.MustRegister(guageTopic)
	prometheus.MustRegister(guageCustom)

	// 设置指标值
	testRaw()
	testTopic()
	testCustom()

	// 创建一个HTTP处理器来暴露指标
	http.Handle("/metrics", promhttp.Handler())

	// 启动Web服务器
	http.ListenAndServe(":8082", nil)

}
